==> nextcloud-31.0.9.tgz: nextcloud/apps/user_status/l10n/el.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Πρόσφατες καταστάσεις",
    "No recent status changes" : "Δεν υπάρχουν πρόσφατες αλλαγές κατάστασης",
    "In a meeting" : "Σε συνάντηση",
    "Commuting" : "Μετακίνηση προς την εργασία",
    "Out sick" : "Αναρρωτική άδεια",
    "Vacationing" : "Διακοπάρω",
    "Out of office" : "Εκτός γραφείου",
    "Working remotely" : "Εργασία εξ αποστάσεως",
    "In a call" : "Σε μια κλήση",
    "User status" : "Κατάσταση χρήστη",
    "Clear status after" : "Εκκαθάριση κατάστασης μετά από",
    "What is your status?" : "Ποια είναι η κατάστασή σας;",
    "There was an error saving the status" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της κατάστασης",
    "There was an error clearing the status" : "Παρουσιάστηκε σφάλμα κατά την εκκαθάριση της κατάστασης",
    "Online status" : "Κατάσταση σε σύνδεση",
    "Status message" : "Μήνυμα κατάστασης",
    "Clear status message" : "Εκκαθάριση μηνύματος κατάστασης",
    "Set status message" : "Ορισμός μηνύματος κατάστασης",
    "Don't clear" : "Να μη γίνεται εκκαθάριση",
    "Today" : "Σήμερα",
    "This week" : "Αυτή την εβδομάδα",
    "Online" : "Σε σύνδεση",
    "Away" : "Λείπω",
    "Do not disturb" : "Μην ενοχλείτε",
    "Invisible" : "Αόρατος",
    "Offline" : "Εκτός σύνδεσης",
    "Set status" : "Ορισμός κατάστασης",
    "There was an error saving the new status" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της νέας κατάστασης",
    "30 minutes" : "30 λεπτά",
    "1 hour" : "1 ώρα",
    "4 hours" : "4 ώρες",
    "Busy" : "Απασχολημένος",
    "Mute all notifications" : "Σίγαση όλων των ειδοποιήσεων",
    "Appear offline" : "Εμφάνιση εκτός σύνδεσης"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/user_status/l10n/el.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Πρόσφατες καταστάσεις",
    "No recent status changes" : "Δεν υπάρχουν πρόσφατες αλλαγές κατάστασης",
    "In a meeting" : "Σε συνάντηση",
    "Commuting" : "Μετακίνηση προς την εργασία",
    "Out sick" : "Αναρρωτική άδεια",
    "Vacationing" : "Διακοπάρω",
    "Out of office" : "Εκτός γραφείου",
    "Working remotely" : "Εργασία εξ αποστάσεως",
    "In a call" : "Σε μια κλήση",
    "Be right back" : "Θα επιστρέψω σύντομα",
    "User status" : "Κατάσταση χρήστη",
    "Clear status after" : "Εκκαθάριση κατάστασης μετά από",
    "Emoji for your status message" : "Emoji για το μήνυμα κατάστασής σας",
    "What is your status?" : "Ποια είναι η κατάστασή σας;",
    "Predefined statuses" : "Προκαθορισμένες καταστάσεις",
    "Previously set" : "Προηγουμένως ορισμένη",
    "Reset status" : "Επαναφορά κατάστασης",
    "Reset status to \"{icon} {message}\"" : "Επαναφορά κατάστασης σε «{icon} {message}»",
    "Reset status to \"{message}\"" : "Επαναφορά κατάστασης σε «{message}»",
    "Reset status to \"{icon}\"" : "Επαναφορά κατάστασης σε «{icon}»",
    "There was an error saving the status" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της κατάστασης",
    "There was an error clearing the status" : "Παρουσιάστηκε σφάλμα κατά την εκκαθάριση της κατάστασης",
    "There was an error reverting the status" : "Παρουσιάστηκε σφάλμα κατά την επαναφορά της κατάστασης",
    "Online status" : "Κατάσταση σε σύνδεση",
    "Status message" : "Μήνυμα κατάστασης",
    "Set absence period" : "Ορισμός περιόδου απουσίας",
    "Set absence period and replacement" : "Ορισμός περιόδου απουσίας και αντικαταστάτη",
    "Your status was set automatically" : "Η κατάστασή σας ορίστηκε αυτόματα",
    "Clear status message" : "Εκκαθάριση μηνύματος κατάστασης",
    "Set status message" : "Ορισμός μηνύματος κατάστασης",
    "Don't clear" : "Να μη γίνεται εκκαθάριση",
    "Today" : "Σήμερα",
    "This week" : "Αυτή την εβδομάδα",
    "Online" : "Σε σύνδεση",
    "Away" : "Λείπω",
    "Do not disturb" : "Μην ενοχλείτε",
    "Invisible" : "Αόρατος",
    "Offline" : "Εκτός σύνδεσης",
    "Set status" : "Ορισμός κατάστασης",
    "There was an error saving the new status" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση της νέας κατάστασης",
    "30 minutes" : "30 λεπτά",
    "1 hour" : "1 ώρα",
    "4 hours" : "4 ώρες",
    "Busy" : "Απασχολημένος",
    "Mute all notifications" : "Σίγαση όλων των ειδοποιήσεων",
    "Appear offline" : "Εμφάνιση εκτός σύνδεσης"
},
"nplurals=2; plural=(n != 1);");
